from _add_use_case_scripts.requestPost  import postLayersToSwagger, postTableToSwagger
def add_table(use_case: str, table_name: str):
    '''
    take the columns and add the mappings at the server
    replace all "/"'s in the internal representation with a "_"
    '''

    columns = [
        # "docType",
        "videoId",
        "Video_Token",
        "replyTo",
        "Created",
        "Duration",
        "videoResolution",
        "Label",
        "ThreadId",
        "Position",
        "ModifiedDate",
        "Views",
        "ModeratedBy",
        "CommunityManagerNotes",
        "Rewards",
        "Video_State",
        "Video_Type"
    ]
    
    columns = { c : c for c in columns }
    columns["UniqueID"] = "videoId"

    table = {
        "name": table_name,
        "mappings": columns
    }

    postTableToSwagger(use_case,table)

def add_layers(use_case:str, table_name: str):
    layers = [
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Manager_Layer",
            "properties": [
                "UniqueID",
                "ModifiedDate",
                "ModeratedBy",
                "Video_State",
                "Video_Type"
            ],
            "cluster_properties": [
                "ModeratedBy",
                "Video_State"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Video_Popularity_Layer",
            "properties": [
                "UniqueID",
                "Label",
                "Created",
                "Views",
                "Rewards",
                "Video_State",
                "Video_Type"
            ],
            "cluster_properties": [
                "Views",
                "Video_Type"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Video_Age_Layer",
            "properties": [
                "UniqueID",
                "Label",
                "Created",
                "Views",
                "Rewards",
                "Video_State",
                "Video_Type"
            ],
            "cluster_properties": [
                "Created"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Rewards_Layer",
            "properties": [
                "UniqueID",
                "Label",
                "Created",
                "Views",
                "Rewards",
                "Video_State",
                "Video_Type"
            ],
            "cluster_properties": [
                "Rewards"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Video_Lenght_Layer",
            "properties": [
                "UniqueID",
                "Created",
                "Views",
                "Duration",
                "Video_State",
                "Video_Type"
            ],
            "cluster_properties": [
                "Duration"
            ]
        },
        {
            "use_case": use_case,
            "table": table_name,
            "name": "Video_Resolution_Layer",
            "properties": [
                "UniqueID",
                "Created",
                "Views",
                "videoResolution",
                "Video_State",
                "Video_Type"
            ],
            "cluster_properties": [
                "videoResolution"
            ]
        }
    ]

    postLayersToSwagger(use_case,layers)    

def main(use_case: str):
    print("Video")
    table_name = "video"
    add_table(use_case,table_name)
    add_layers(use_case,table_name)